@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 __all__ = ["polling", "wsrpc", "central_unit"]
 
 from .polling import CentralUnitPolling
@@ -7,6 +9,7 @@ from .wsrpc import (
     InvalidMessage,
     ConnectionClosed,
     CU_WSRPC_VERSION,
+    CU_WSRPC_VERSION_A,
 )
 from .central_unit import (
     SwitchBeeError,
@@ -17,6 +20,6 @@ from .central_unit import (
 
 def is_wsrpc_api(api: CentralUnitPolling | CentralUnitWsRPC) -> bool:
     assert isinstance(api.version, str)
-    if CU_WSRPC_VERSION in api.version:
+    if CU_WSRPC_VERSION in api.version or CU_WSRPC_VERSION_A in api.version:
         return True
     return False
